@@ -21,11 +21,11 @@
 
 /* $Id$ */
 
-define('SOLR_MAJOR_VERSION', 1);
-define('SOLR_MINOR_VERSION', 1);
+define('SOLR_MAJOR_VERSION', 2);
+define('SOLR_MINOR_VERSION', 0);
 define('SOLR_PATCH_VERSION', 0);
 
-define('SOLR_EXTENSION_VERSION', '1.1.0');
+define('SOLR_EXTENSION_VERSION', '2.0.0b');
 
 /**
  * Returns the current version of the Apache Solr extension
@@ -281,32 +281,32 @@ class SolrClient
      * Adds a document to the index
      * 
      * @param SolrInputDocument $doc
-     * @param bool $allowDups
-     * @param int $commitWithin
+     * @param bool $overwrite
+     * @param int $commitWithin 0 means disabled
      * @return SolrUpdateResponse
      */
-    public function addDocument(SolrInputDocument &$doc, $allowDups, $commitWithin) {}
+    public function addDocument(SolrInputDocument &$doc, $overwrite = true, $commitWithin = 0) {}
     
     /**
      * Adds a collection of SolrInputDocument instances to the index
      *  
      * @param array $doc An array of SolrInputDocument objects
-     * @param bool $allowDups
+     * @param bool $overwrite
      * @param int $commitWithin
      * @return SolrUpdateResponse
      */
-    public function  addDocuments(array &$docs, $allowDups, $commitWithin) {}
+    public function  addDocuments(array &$docs, $overwrite = true, $commitWithin = 0) {}
     
     
     /**
      * Finalizes all add/deletes made to the index
      * 
-     * @param bool $waitFlush
+     * @param bool $softCommit
      * @param bool $waitSearcher
      * @param bool $expungeDeletes
      * @return SolrUpdateResponse
      */
-    public function commit($waitFlush = true, $waitSearcher = true, $expungeDeletes = false) {}
+    public function commit($softCommit = false, $waitSearcher = true, $expungeDeletes = false) {}
 
     /**
      * Deletes the document with the specified ID. 
@@ -360,11 +360,11 @@ class SolrClient
      * Defragments the index for faster search performance
      * 
      * @param int $maxSegments
-     * @param int $waitFlush
+     * @param int $softCommit
      * @param bool $waitSearcher
      * @return SolrUpdateResponse
      */
-    public function optimize($maxSegments = 1, $waitFlush = true, $waitSearcher = true) {}
+    public function optimize($maxSegments = 1, $softCommit = false, $waitSearcher = true) {}
     
     /**
      * Checks if Solr server is still up
