@@ -213,13 +213,13 @@ ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(SolrClient_addDocument_args, SOLR_ARG_PASS_REMAINING_BY_REF_FALSE, SOLR_METHOD_RETURN_REFERENCE_TRUE, 1)
 ZEND_ARG_OBJ_INFO(SOLR_ARG_PASS_BY_REF_TRUE, doc, SolrInputDocument, SOLR_ARG_ALLOW_NULL_FALSE)
-ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, allowDups)
+ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, overwrite)
 ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, commitWithin)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(SolrClient_addDocuments_args, SOLR_ARG_PASS_REMAINING_BY_REF_FALSE, SOLR_METHOD_RETURN_REFERENCE_TRUE, 1)
 ZEND_ARG_ARRAY_INFO(SOLR_ARG_PASS_BY_REF_TRUE, docs, SOLR_ARG_ALLOW_NULL_FALSE)
-ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, allowDups)
+ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, overwrite)
 ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, commitWithin)
 ZEND_END_ARG_INFO()
 
@@ -232,15 +232,14 @@ ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, responseWriter)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(SolrClient_commit_args, SOLR_ARG_PASS_REMAINING_BY_REF_FALSE, SOLR_METHOD_RETURN_REFERENCE_TRUE, 0)
-ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, maxSegments)
-ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, waitFlush)
+ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, softCommit)
 ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, waitSearcher)
 ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, expungeDeletes)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(SolrClient_optimize_args, SOLR_ARG_PASS_REMAINING_BY_REF_FALSE, SOLR_METHOD_RETURN_REFERENCE_TRUE, 0)
 ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, maxSegments)
-ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, waitFlush)
+ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, softCommit)
 ZEND_ARG_INFO(SOLR_ARG_PASS_BY_REF_FALSE, waitSearcher)
 ZEND_END_ARG_INFO()
 
@@ -1103,15 +1102,12 @@ PHP_RINIT_FUNCTION(solr)
 	/* Initial size of the HashTable */
 	uint nSize             = SOLR_INITIAL_HASH_TABLE_SIZE;
 
-	/* Always NULL. Kept for API backward compatibility purposes only */
-	hash_func_t pHashFunction    = NULL;
-
 	ALLOC_HASHTABLE(SOLR_GLOBAL(documents));
 	ALLOC_HASHTABLE(SOLR_GLOBAL(clients));
 	ALLOC_HASHTABLE(SOLR_GLOBAL(params));
 
 	/* Initialize the HashTable for directory for SolrInputDocuments */
-	if (zend_hash_init(SOLR_GLOBAL(documents), nSize, pHashFunction, solr_destroy_document, persistent) == FAILURE) {
+	if (zend_hash_init(SOLR_GLOBAL(documents), nSize, NULL, solr_destroy_document, persistent) == FAILURE) {
 		FREE_HASHTABLE(SOLR_GLOBAL(documents));
 		FREE_HASHTABLE(SOLR_GLOBAL(clients));
 		FREE_HASHTABLE(SOLR_GLOBAL(params));
@@ -1122,7 +1118,7 @@ PHP_RINIT_FUNCTION(solr)
 	}
 
 	/* Initialize the HashTable for directory of SolrClients */
-	if (zend_hash_init(SOLR_GLOBAL(clients), nSize, pHashFunction, solr_destroy_client, persistent) == FAILURE) {
+	if (zend_hash_init(SOLR_GLOBAL(clients), nSize, NULL, solr_destroy_client, persistent) == FAILURE) {
 		FREE_HASHTABLE(SOLR_GLOBAL(documents));
 		FREE_HASHTABLE(SOLR_GLOBAL(clients));
 		FREE_HASHTABLE(SOLR_GLOBAL(params));
@@ -1133,7 +1129,7 @@ PHP_RINIT_FUNCTION(solr)
 	}
 
 	/* Initialize the HashTable for directory of SolrParams */
-	if (zend_hash_init(SOLR_GLOBAL(params), nSize, pHashFunction, solr_destroy_params, persistent) == FAILURE) {
+	if (zend_hash_init(SOLR_GLOBAL(params), nSize, NULL, solr_destroy_params, persistent) == FAILURE) {
 		FREE_HASHTABLE(SOLR_GLOBAL(documents));
 		FREE_HASHTABLE(SOLR_GLOBAL(clients));
 		FREE_HASHTABLE(SOLR_GLOBAL(params));
