@@ -23,6 +23,8 @@
 #ifndef SOLRCLIENT_H
 #define SOLRCLIENT_H
 
+/* #define SOLR_MEM_DEBUG 1 */
+
 #include <main/php.h>
 
 #ifdef HAVE_CONFIG_H
@@ -642,7 +644,10 @@ PHP_SOLR_API void solr_escape_query_chars(solr_string_t *sbuilder, solr_char_t *
 /* }}} */
 
 /* {{{ Solr Server Exception Handling */
-PHP_SOLR_API int solr_get_html_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC);
+PHP_SOLR_API int solr_get_xml_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC);
+PHP_SOLR_API int solr_get_json_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC);
+PHP_SOLR_API int solr_get_phpnative_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC);
+PHP_SOLR_API int hydrate_error_zval(zval *response, solr_exception_t *exceptionData TSRMLS_DC);
 /* }}} */
 
 /* {{{ Solr Object Handlers */
