@@ -515,31 +515,29 @@ PHP_SOLR_API void solr_free_options(solr_client_options_t *options)
 /* {{{ PHP_SOLR_API void solr_destroy_client(void *client) */
 PHP_SOLR_API void solr_destroy_client(void *client)
 {
-	solr_client_t *solr_client = (solr_client_t *) client;
+    solr_client_t *solr_client = (solr_client_t *) client;
 
-	if (solr_client)
-	{
-		solr_free_options(&(solr_client->options));
+    if (solr_client)
+    {
+        solr_free_options(&(solr_client->options));
 
-		solr_free_handle(&(solr_client->handle));
+        solr_free_handle(&(solr_client->handle));
 
-		solr_client = NULL;
-	}
+        solr_client = NULL;
+    }
 }
 /* }}} */
 
-/* {{{ PHP_SOLR_API int solr_get_html_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC) */
-PHP_SOLR_API int solr_get_html_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC)
+/* {{{ PHP_SOLR_API int solr_get_xml_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC) */
+PHP_SOLR_API int solr_get_xml_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC)
 {
+    xmlDoc *doc = xmlReadMemory((const char *)buffer.str, buffer.len, NULL, "UTF-8", XML_PARSE_RECOVER);
+
     xmlXPathContext *xpathContext = NULL;
     xmlXPathObject *xpathObject = NULL;
-    // find the error description (handled through jetty html page)
-    xmlChar *xpathExpression = "/html/body/p/pre";
-    xmlNodeSet *nodes = NULL;
-    
-    zval *tmp_p;
-    xmlDoc *doc = xmlReadMemory((xmlChar *)buffer.str, buffer.len, NULL, "UTF-8", XML_PARSE_RECOVER);
-
+    xmlChar *xpathExpression = (unsigned char *)"/response/lst[@name='error']";
+    xmlNode * nodeCurser;
+    const unsigned char * nodePropName = (const unsigned char *)"name";
     if (!doc)
     {
         php_error_docref(NULL TSRMLS_CC, E_WARNING, "Error loading XML document");
@@ -568,36 +566,155 @@ PHP_SOLR_API int solr_get_html_error(solr_string_t buffer, solr_exception_t *exc
         xmlFreeDoc(doc);
         return 1;
     }
-    if(xpathObject->nodesetval->nodeNr < 1)
+    nodeCurser = xpathObject->nodesetval->nodeTab[0]->children;
+
+    while (nodeCurser != NULL)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "Xpath Error: no elements found");
-        xmlXPathFreeObject(xpathObject);
-        xmlFreeDoc(doc);
-        return 1;
-
+        if (xmlHasProp(nodeCurser, nodePropName))
+        {
+            if (strcmp((const char *)xmlGetProp(nodeCurser,nodePropName), (const char *)"msg") == 0)
+            {
+                exceptionData->message = (solr_char_t *)estrdup((const char *)nodeCurser->children->content);
+            } else if(strcmp((const char *)xmlGetProp(nodeCurser,nodePropName),"code") == 0) {
+                exceptionData->code = atoi((const char *)nodeCurser->children->content);
+            }
+        }
+        nodeCurser = nodeCurser->next;
     }
 
-    // trim error message
-    MAKE_STD_ZVAL(tmp_p);
-    ZVAL_STRING(tmp_p, xpathObject->nodesetval->nodeTab[0]->children->content, 0);
-    php_trim( (char *) Z_STRVAL_P(tmp_p), Z_STRLEN_P(tmp_p), NULL, 0, tmp_p, 3 TSRMLS_CC);
-
-    exceptionData->message = (solr_char_t *) estrdup(Z_STRVAL_P(tmp_p));
-
-    // hardcoded since solr 3.x handles exceptions with jetty
-    exceptionData->code = 400;
-    zval_ptr_dtor(&tmp_p);
-
     xmlXPathFreeObject(xpathObject);
     xmlXPathFreeContext(xpathContext);
 
     xmlFreeDoc(doc);
+    return 0;
+}
+/* }}} */
+
+/* {{{ PHP_SOLR_API int hydrate_error_zval(zval *response, solr_exception_t *exceptionData TSRMLS_DC) */
+PHP_SOLR_API int hydrate_error_zval(zval *response, solr_exception_t *exceptionData TSRMLS_DC)
+{
+
+    char * key = "error";
+    int keyLen = 5;
+    zval **errorPP = (zval **) NULL, *errorP;
+
+    zval **msgZvalPP=(zval **) NULL, **codeZval = (zval **) NULL;
+
+    if( zend_hash_find( Z_ARRVAL_P(response), key, keyLen+1, (void **) &errorPP) == SUCCESS)
+    {
+        errorP = *errorPP;
+        if(zend_hash_exists(HASH_OF(errorP), "msg", sizeof("msg")))
+        {
+            if(zend_hash_find(Z_ARRVAL_P(errorP), "msg", sizeof("msg"), (void **) &msgZvalPP) == SUCCESS)
+            {
+                exceptionData->message = (solr_char_t *)estrdup(Z_STRVAL(**msgZvalPP));
+            }else{
+                php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Undefined variable: %s","msg" );
+                return 1;
+            }
+        }else{
+            php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Unable to find %s in error response zval","message" );
+            return 1;
+        }
+
+        if(zend_hash_find(Z_ARRVAL_P(errorP), "code", sizeof("code"), (void **) &codeZval) == SUCCESS)
+        {
+            exceptionData->code = (int)Z_LVAL_PP(codeZval);
+        } else {
+            php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Unable to find element with key %s in error response zval","code" );
+            return 1;
+        }
+    } else {
+        php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Unable to find %s in error response","error element" );
+        return 1;
+    }
 
     return 0;
 }
 /* }}} */
 
-/* {{{ PHP_SOLR_API void solr_throw_solr_server_exception(solr_client_t *client,const char * requestType TSRMLS_DC) */
+/* {{{ PHP_SOLR_API int solr_get_json_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC) */
+PHP_SOLR_API int solr_get_json_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC)
+{
+    zval *jsonResponse;
+    zval *errorP;
+    zval **errorPP=(zval **)NULL,**msgZvalPP=(zval **)NULL,**codeZval=(zval **)NULL;
+
+    HashTable *errorHashTable;
+
+    char * key = "error";
+    int keyLen = 5;
+    long nSize = 1000;
+
+    MAKE_STD_ZVAL(jsonResponse);
+
+    php_json_decode(jsonResponse, (char *) buffer.str, buffer.len, 1, 1024L TSRMLS_CC);
+
+    if (Z_TYPE_P(jsonResponse) == IS_NULL)
+    {
+        zval_ptr_dtor(&jsonResponse);
+        php_error_docref(NULL TSRMLS_CC, E_WARNING, "Unable to parse Solr Server Error Response. JSON serialization error");
+        return 1;
+    }
+
+    ALLOC_HASHTABLE(errorHashTable);
+    zend_hash_init(errorHashTable, nSize, NULL, NULL, 0);
+    if( zend_hash_find( Z_ARRVAL_P(jsonResponse), key, keyLen+1, (void **) &errorPP) == SUCCESS)
+    {
+        errorP = *errorPP;
+
+        if(zend_hash_exists(HASH_OF(errorP), "msg", sizeof("msg")))
+        {
+            if(zend_hash_find(Z_ARRVAL_P(errorP), "msg", sizeof("msg"), (void **) &msgZvalPP) == SUCCESS)
+            {
+                exceptionData->message = (solr_char_t *)estrdup(Z_STRVAL(**msgZvalPP));
+            }else{
+                php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Undefined variable: %s","msg" );
+            }
+        }else{
+            php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Unable to find %s in error response zval","message" );
+            return 1;
+        }
+
+        if(zend_hash_find(Z_ARRVAL_P(errorP), "code", sizeof("code"), (void **) &codeZval) == SUCCESS)
+        {
+            exceptionData->code = (int)Z_LVAL_PP(codeZval);
+        }else{
+            php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Unable to find %s in json error response","code" );
+        }
+    }else{
+        php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Undefined variable: %s",key );
+    }
+
+    zval_ptr_dtor(&jsonResponse);
+    zend_hash_destroy(errorHashTable);
+    FREE_HASHTABLE(errorHashTable);
+    return 0;
+}
+/* }}} */
+
+/* {{{ PHP_SOLR_API int solr_get_phpnative_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC) */
+PHP_SOLR_API int solr_get_phpnative_error(solr_string_t buffer, solr_exception_t *exceptionData TSRMLS_DC)
+{
+
+    zval * response_obj;
+    php_unserialize_data_t var_hash;
+    const unsigned char * raw_resp = (const unsigned char *) buffer.str;
+    const unsigned char * str_end = (const unsigned char *) (buffer.str + buffer.len);
+
+    ALLOC_INIT_ZVAL(response_obj);
+    PHP_VAR_UNSERIALIZE_INIT(var_hash);
+
+    php_var_unserialize(&response_obj, &raw_resp, str_end, &var_hash TSRMLS_CC);
+    hydrate_error_zval(response_obj, exceptionData TSRMLS_CC);
+    PHP_VAR_UNSERIALIZE_DESTROY(var_hash);
+    zval_ptr_dtor(&response_obj);
+    return 0;
+}
+/* }}} */
+
+/* {{{ PHP_SOLR_API void solr_throw_solr_server_exception(solr_client_t *client,const char * requestType TSRMLS_DC)
+     parse the solr server response and throw a SolrServerException */
 PHP_SOLR_API void solr_throw_solr_server_exception(solr_client_t *client,const char * requestType TSRMLS_DC)
 {
     const char * response_writer = (char *) client->options.response_writer.str;
@@ -605,8 +722,31 @@ PHP_SOLR_API void solr_throw_solr_server_exception(solr_client_t *client,const c
     exceptionData = (solr_exception_t*) emalloc(sizeof(solr_exception_t ));
     exceptionData->code = 0;
     memset(exceptionData, 0, sizeof(solr_exception_t));
+    if( 0 == strcmp(response_writer, SOLR_XML_RESPONSE_WRITER)){
 
-    solr_get_html_error(client->handle.response_body.buffer, exceptionData TSRMLS_CC);
+        if(solr_get_xml_error(client->handle.response_body.buffer, exceptionData TSRMLS_CC) != SUCCESS)
+        {
+            // fallback to normal exception
+            solr_throw_exception_ex(solr_ce_SolrClientException, SOLR_ERROR_1010 TSRMLS_CC, SOLR_FILE_LINE_FUNC, SOLR_ERROR_1010_MSG, requestType, SOLR_RESPONSE_CODE_BODY);
+            return;
+        }
+    }
+
+    if( 0 == strcmp(response_writer, SOLR_JSON_RESPONSE_WRITER))
+    {
+        if(solr_get_json_error(client->handle.response_body.buffer, exceptionData TSRMLS_CC) != SUCCESS)
+        {
+            solr_throw_exception_ex(solr_ce_SolrClientException, SOLR_ERROR_1010 TSRMLS_CC, SOLR_FILE_LINE_FUNC, SOLR_ERROR_1010_MSG, requestType, SOLR_RESPONSE_CODE_BODY);
+        }
+    }
+
+    if( 0 == strcmp(response_writer, SOLR_PHP_NATIVE_RESPONSE_WRITER) || 0 == strcmp(response_writer, SOLR_PHP_SERIALIZED_RESPONSE_WRITER))
+    {
+        if(solr_get_phpnative_error(client->handle.response_body.buffer,exceptionData TSRMLS_CC) != SUCCESS)
+        {
+            php_error_docref(NULL TSRMLS_CC, E_NOTICE, "Unable to parse serialized php response" );
+        }
+    }
 
     if(exceptionData->code == 0){
         solr_throw_exception_ex(solr_ce_SolrClientException, SOLR_ERROR_1010 TSRMLS_CC, SOLR_FILE_LINE_FUNC, SOLR_ERROR_1010_MSG, requestType, SOLR_RESPONSE_CODE_BODY);
