@@ -268,8 +268,7 @@ PHP_SOLR_API void solr_escape_query_chars(solr_string_t *sbuilder, solr_char_t *
 	 * Lucene supports escaping special characters that are part of the query syntax.
 	 *
 	 * The current list special characters are
-	 *
-	 * + - && || ! ( ) { } [ ] ^ " ~ * ? : \
+	 * + - && || ! ( ) { } [ ] ^ " ~ * ? : \ /
 	 *
 	 * These characters are part of the query syntax and must be escaped
 	 */
@@ -286,6 +285,7 @@ enter_switchboard :
 			case '('  :
 			case ')'  :
 			case ':'  :
+			case '/'  :
 
 			case '^'  :
 			case '['  :
@@ -1040,17 +1040,11 @@ PHP_SOLR_API int solr_is_supported_response_writer(const solr_char_t * response_
 		return 0;
 	}
 
-	if (0 == strcmp(response_writer, SOLR_PHP_NATIVE_RESPONSE_WRITER))
+	if (0 == strcmp(response_writer, SOLR_PHP_SERIALIZED_RESPONSE_WRITER))
 	{
 		return 1;
 	}
 
-	if(0 == strcmp(response_writer, SOLR_PHP_SERIALIZED_RESPONSE_WRITER))
-	{
-	    return 1;
-	}
-
-
 	if (0 == strcmp(response_writer, SOLR_XML_RESPONSE_WRITER))
 	{
 		return 1;
@@ -1182,6 +1176,28 @@ PHP_SOLR_API int solr_json_to_php_native(solr_string_t *buffer, const solr_char_
 
 	return (int) json_error;
 }
+
+PHP_SOLR_API long solr_get_json_last_error(TSRMLS_D)
+{
+    long json_error;
+    zval json_last_error_ret_val, **object_pp;
+
+    zval *json_last_error_params[] = {NULL};
+    zval json_last_error_function_name;
+
+    ZVAL_STRINGL(&json_last_error_function_name, "json_last_error", sizeof("json_last_error"), 0);
+    /* object instance to perform the method call */
+    object_pp = (zval **) NULL;
+    call_user_function(EG(function_table), object_pp, &json_last_error_function_name, &json_last_error_ret_val, 0, json_last_error_params TSRMLS_CC);
+
+    json_error = Z_LVAL(json_last_error_ret_val);
+
+    zval_dtor(&json_last_error_ret_val);
+
+    return json_error;
+}
+
+
 /* }}} */
 
 /*
